function Aloc = STIMA_Lapl_Nitsche(Vertices, bdedges, alpha, varargin)

    Aloc = STIMA_Lapl_LFE(Vertices);

    if ~isempty(bdedges)
        % Calculate area of triangle
        a = norm(Vertices(1,:) - Vertices(2,:));
        b = norm(Vertices(2,:) - Vertices(3,:));
        c = norm(Vertices(1,:) - Vertices(3,:));
        s = (a+b+c)/2;
        area = sqrt(s * (s-a) * (s-b) * (s-c));

        % Calculate the gradients of each shape function
        grads = [Vertices(2,2) - Vertices(3,2),... 
                 Vertices(3,1) - Vertices(2,1);...
                 Vertices(3,2) - Vertices(1,2),...
                 Vertices(1,1) - Vertices(3,1);...
                 Vertices(1,2) - Vertices(2,2),...
                 Vertices(2,1) - Vertices(1,1)];
        grads = grads / 2 / area;

        for i = bdedges
            % Get the vertices of the edge
            idx = setdiff(1:3, i);
            edgelen = norm(Vertices(idx(1),:) -... 
                           Vertices(idx(2),:));

            % Alpha term
            aterm = [2, 1; 1, 2] * edgelen/6 * alpha;
            Aloc(idx,idx) = Aloc(idx,idx) + aterm;

            % Nitsche terms
            n = -grads(i,:) / norm(grads(i,:));
            nterm = repmat(dot(grads, repmat(n,3,1), 2)', 3, 1);
            nterm(i,:) = 0;
            Aloc = Aloc - (nterm + nterm')*edgelen/2;
        end
    end

end
